"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var account_operations_1 = require("./account-operations");
var AccountTransactions = /** @class */ (function () {
    function AccountTransactions(id, session) {
        this.id = id;
        this.session = session;
    }
    AccountTransactions.prototype.addAuthDescriptor = function (authDescriptor) {
        return this.session.blockchain.transactionBuilder()
            .add(account_operations_1.addAuthDescriptor(this.id, this.session.user.authDescriptor.id, authDescriptor))
            .add(account_operations_1.nop())
            .build([this.session.user.authDescriptor.signers, authDescriptor.signers].flat())
            .sign(this.session.user.keyPair);
    };
    AccountTransactions.prototype.deleteAllAuthDescriptorsExclude = function (authDescriptor) {
        return this.session.blockchain.transactionBuilder()
            .add(account_operations_1.deleteAllAuthDescriptorsExclude(this.id, authDescriptor.id))
            .buildAndSign(this.session.user);
    };
    AccountTransactions.prototype.deleteAuthDescriptor = function (authDescriptor) {
        return this.session.blockchain.transactionBuilder()
            .add(account_operations_1.deleteAuthDescriptor(this.id, this.session.user.authDescriptor.id, authDescriptor.id))
            .buildAndSign(this.session.user);
    };
    AccountTransactions.prototype.transferInputsToOutputs = function (inputs, outputs) {
        return this.session.blockchain.transactionBuilder()
            .add(account_operations_1.transfer(inputs, outputs))
            .add(account_operations_1.nop())
            .buildAndSign(this.session.user);
    };
    AccountTransactions.prototype.xcTransfer = function (destinationChainId, destinationAccountId, assetId, amount) {
        return this.session.blockchain.transactionBuilder()
            .add(this.xcTransferOp(destinationChainId, destinationAccountId, assetId, amount))
            .add(account_operations_1.nop())
            .buildAndSign(this.session.user);
    };
    /* Operation */
    AccountTransactions.prototype.xcTransferOp = function (destinationChainId, destinationAccountId, assetId, amount) {
        var source = [
            this.id,
            assetId,
            this.session.user.authDescriptor.id,
            amount,
            []
        ];
        var target = [
            destinationAccountId,
            []
        ];
        var hops = [
            destinationChainId
        ];
        return account_operations_1.xcTransfer(source, target, hops);
    };
    return AccountTransactions;
}());
exports.default = AccountTransactions;
//# sourceMappingURL=account-transactions.js.map